#!/bin/sh

# =============================================================================
# A backup script for mbed.org
# =============================================================================
# Copyright (c) 2010 Shinichiro Nakamura (CuBeatSystems)
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
# =============================================================================

#
# Variables.
#
MBED="http://mbed.org/"
AREALIST="programs libraries"
PAGELIST="1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20"
USER="$1"
OUTDIR="./$1"

#
# Check the argument.
#
if [ ! "$#" = "1" ]
then
    echo "mbed_backup.sh [user]"
    exit
fi

#
# Create the output directories.
#
if [ ! -d $OUTDIR ]
then
    mkdir $OUTDIR
    if [ ! "$?" = "0" ]
    then
        echo "Failure to create the output directory."
        exit
    fi
fi

for AREA in $AREALIST
do
    if [ ! -d $OUTDIR/$AREA ]
    then
        mkdir $OUTDIR/$AREA
        if [ ! "$?" = "0" ]
        then
            echo "Failure to create the output directory."
            exit
        fi
    fi
done

#
# Backup.
#
for AREA in $AREALIST
do
    echo "[$AREA of $USER]"
    for PAGE in $PAGELIST
    do
        URL="$MBED/users/$USER/$AREA?page=$PAGE"
        PROGLIST=`wget -q $URL -O - | tr '"' '\n' | grep "$USER/$AREA"`
        if [ "$PROGLIST" = "" ]
        then
            echo "  Done."
            break
        fi
        for PROG in $PROGLIST
        do
            ZIP=`wget -q $MBED/$PROG -O - | tr '"' '\n' | grep "format=zip"`
            if [ ! "$ZIP" = "" ]
            then
                TARGET=`echo $ZIP | sed -e "s/.*$AREA\///g" | sed -e "s/\?.*//g" | sed -e "s/\//-/g"`
                wget -q $ZIP -O "$OUTDIR/$AREA/$TARGET.zip"
                if [ "$?" = "0" ]
                then
                    echo "  Downloaded : $TARGET"
                fi
            fi
        done
    done
done

